@@ -43,6 +43,7 @@ class SecurityLogger(ContextDecorator, local):
 
                 post_revision_commit.connect(self._post_revision_commit, weak=False)
         self.backend_logs = AttrDict()
+        self.stream = None
 
     def _get_parent_with_id(self):
         parent = self.parent
@@ -90,8 +91,19 @@ class SecurityLogger(ContextDecorator, local):
         If log context manager is active input logged request, command
         log or celery task run log is joined with revision via related objects.
         """
-        self.update_extra_data({
-            'reversion': {
-                'revision_id': kwargs['revision_id'] if 'revision_id' in kwargs else kwargs['revision'].id
-            }
+        reversion_data = self._extra_data['reversion'] = self._extra_data.get('reversion', {
+            'revisions': [],
+            'total_count': 0
         })
+        if reversion_data['total_count'] < settings.LOG_MAX_REVISIONS_COUNT:
+            reversion_data['revisions'].append({
+                'id': kwargs['revision_id'] if 'revision_id' in kwargs else kwargs['revision'].id
+            })
+        reversion_data['total_count'] += 1
+
+
+def get_last_logger(name):
+    for logger in SecurityLogger.loggers[::-1]:
+        if logger.name == name:
+            return logger
+    return None
