@@ -3,7 +3,7 @@ from datetime import timedelta
 from django.conf import settings
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
-from django.urls import resolve
+from django.urls import resolve, Resolver404
 
 from ipware.ip import get_client_ip
 
@@ -25,7 +25,7 @@ class ThrottlingValidator:
             raise ThrottlingException(self.description)
 
     def _validate(self, request):
-        raise NotImplemented
+        raise NotImplementedError
 
     def __repr__(self):
         return '<{} (timeframe={}, throttle_at={}, description={})>'.format(
@@ -80,7 +80,7 @@ class UnsuccessfulLoginThrottlingValidator(LoginThrottlingValidator):
 
 class SuccessfulLoginThrottlingValidator(LoginThrottlingValidator):
 
-    slug = InputRequestSlug.SUCCESSFUL_LOGIN_REQUEST
+    type = InputRequestSlug.SUCCESSFUL_LOGIN_REQUEST
 
     def __init__(self, timeframe, throttle_at, description=_('You have logged in too many times')):
         super().__init__(timeframe, throttle_at, description)
@@ -88,7 +88,7 @@ class SuccessfulLoginThrottlingValidator(LoginThrottlingValidator):
 
 class UnSuccessfulTwoFactorCodeVerificationThrottlingValidator(LoginThrottlingValidator):
 
-    slug = InputRequestSlug.UNSUCCESSFUL_2FA_CODE_VERIFICATION_REQUEST
+    type = InputRequestSlug.UNSUCCESSFUL_2FA_CODE_VERIFICATION_REQUEST
 
     def __init__(self, timeframe, throttle_at, description=_('Too many login attempts')):
         super().__init__(timeframe, throttle_at, description)
@@ -96,7 +96,7 @@ class UnSuccessfulTwoFactorCodeVerificationThrottlingValidator(LoginThrottlingVa
 
 class SuccessfulTwoFactorCodeVerificationThrottlingValidator(LoginThrottlingValidator):
 
-    slug = InputRequestSlug.SUCCESSFUL_2FA_CODE_VERIFICATION_REQUEST
+    type = InputRequestSlug.SUCCESSFUL_2FA_CODE_VERIFICATION_REQUEST
 
     def __init__(self, timeframe, throttle_at, description=_('You have logged in too many times')):
         super().__init__(timeframe, throttle_at, description)
